@@ -1,13 +1,16 @@
 """The module `listutils` contains functions that apply simple mathematical
-operations to lists.
+operations to lists. All functions have a `__doc__` attribute with usage
+instructions.
 
-All functions have a `__doc__` attribute with usage instructions.
+Recommended import procedure is:
+
+from listools import listutils
 
 This library is published under the MIT License.
 """
 
-from .list_lcm import list_lcm
 from .list_gcd import list_gcd
+from .list_lcm import list_lcm
 from .list_mask import list_mask
 from .list_mask_cycle import list_mask_cycle
 from .period_len import period_len
